@@ -28,7 +28,7 @@
 import argparse
 import sys
 
-from typing import Callable, Dict, NamedTuple, Tuple
+from typing import Callable, Dict, NamedTuple, Tuple  # noqa: H301
 
 from . import trivver
 
